#!/bin/csh -f

# test pma function to set de-allocated memory to specified value (driver).
# Copyright (C) 2022  Terence Kelly
# Contact:  tpkelly @ { acm.org, cs.princeton.edu, eecs.umich.edu }
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
# Based on test4.csh.


alias clean 'rm -f test8 pma_backing_file pma_backing_file_initstate pma_backing_file_finalstate t1 t2 zout'

clean

if ("clean" == $1) then
    exit
endif

unlimit coredumpsize

if ( $?PMAALLWARNINGS ) then
    set warningflags = `gawk '{print $1}' gcc_warnings_final`
else
    echo
    echo '****************************************'
    echo '*** using bare minimum warning flags ***'
    echo '****************************************'
    set warningflags = '-Wall -Wextra'
endif

echo ; echo '= = = = = = = = = = compile for warnings'  ; echo
rm -f test8 ; gcc -std=c99 -O3 $warningflags -o test8 test8.c pma.c
echo ; echo '= = = = = = = = = = compile for debugging' ; echo
rm -f test8 ; gcc -std=c99 -g  $warningflags -o test8 test8.c pma.c

# try to ensure that a different range of PRNG seeds is used on every run of this script
set seed = `date '+%s' | gawk '{print int(($1-1600000000)/100)*100}'`
@ lastseed = $seed + 100
while ($seed < $lastseed)
    echo
    echo 'begin seed ' $seed `date +%s.%N` `date`
    rm -f zout t1 t2 pma_backing_file pma_backing_file_initstate pma_backing_file_finalstate
    truncate -s 409600 pma_backing_file
    ./test8 $seed >& zout
    echo 'last line of zout (should declare success):'
    tail -n 1 zout
    gawk '/ASTATE_INIT_BEGIN/,/ASTATE_INIT_END/'   zout | grep -v 'ASTATE_' > t1
    gawk '/ASTATE_FINAL_BEGIN/,/ASTATE_FINAL_END/' zout | grep -v 'ASTATE_' > t2
    echo 'compare initial and final allocator state (should be empty diff):'
    diff t1 t2
    echo 'compare initial vs. final backing file state (should differ in nallocs and nfrees fields only)'
    cmp -l pma_backing_file_initstate pma_backing_file_finalstate |& head
    echo 'max number of live allocated objects'
    grep ' maxL:' zout
    echo 'done ' `date +%s.%N`
    echo
    rm -f zout t1 t2 pma_backing_file pma_backing_file_initstate pma_backing_file_finalstate
    @ seed ++
end

echo ; echo

if ("keep" == $1) then
    exit
endif

clean

